====================
imio.media
====================

This package is used to view video from links. You can add video or photo from a link which accept oembeded protocol. This package has as dependecy collective.oembeded.

* `Source code @ GitHub <https://github.com/imio/imio.media>`_
* `Releases @ PyPI <http://pypi.python.org/pypi/imio.media>`_
* `Documentation @ ReadTheDocs <http://imiomedia.readthedocs.org>`_
* `Continuous Integration @ Travis-CI <http://travis-ci.org/imio/imio.media>`_


This package is tested using Travis CI. The current status is :

.. image:: https://travis-ci.org/IMIO/imio.media.png
    :target: http://travis-ci.org/IMIO/imio.media

.. image:: https://coveralls.io/repos/github/IMIO/imio.media/badge.svg?branch=master
    :target: https://coveralls.io/github/IMIO/imio.media?branch=master

How it works
============

This package is based on collective.oembed.


Installation
============

To install `imio.media` you simply add ``imio.media``
to the list of eggs in your buildout, run buildout and restart Plone.
Then, install `imio.media` using the Add-ons control panel.


Configuration
=============

...
